OC.L10N.register(
    "files_texteditor",
    {
    "This file is too big to be opened. Please download the file instead." : "Este archivo es demasiado grande para ser abierto. Por favor mejor descargue el archivo.",
    "Cannot read the file." : "No se puede leer el archivo.",
    "Invalid file path supplied." : "La ruta de archivo especificada es inválida.",
    "Cannot save file as it has been modified since opening" : "No se puede guardar el archivo pues fue modificado desde que fue abierto.",
    "Insufficient permissions" : "Permisos insuficientes",
    "File path not supplied" : "Ruta de archivo no especificada",
    "File mtime not supplied" : "Mtime del archivo no especificado",
    "saving..." : "guardando...",
    "saved!" : "¡guardado!",
    "failed!" : "¡falló!",
    "Saved" : "Guardado",
    "There was a problem saving your changes. Click to resume editing." : "Hubo un problema al guardar sus cambios. Haga clic para seguir editando.",
    "An error occurred!" : "¡Ocurrió un error!",
    "Text file" : "Archivo de texto"
},
"nplurals=2; plural=(n != 1);");
